@@ -1,8 +1,11 @@
 #' @export
 
 plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
   
-  fit_args <- extract_arguments(output)
+  fit_args <- bgms::extract_arguments(output)
   
   # Give error if save is false
   if(fit_args$save == FALSE){
@@ -77,7 +80,11 @@ plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
 
 plot_complexity_probabilities.bgms <- function(output, ...) {
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   # Give error if save is false
   if(fit_args$save == FALSE){
@@ -141,7 +148,11 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
 
 plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE, show = "all", ...) {
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   if(!fit_args$edge_selection){
     stop("The plot cannot be obtained for this model fit as no posterior edge inclusion probabilities were obtained. Rerun the model fit and set 'edge_selection = TRUE'.")
@@ -160,7 +171,7 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
   default_args <- list(
     colors = c("#36648b", "#990000", "#bfbfbf"),
     colnames = colnames(output$parameters),
-    layout_avg = qgraph::averageLayout(output$parameters*output$structure),
+    layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     theme = "TeamFortress",
     legend = TRUE,
     vsize = 10,
@@ -187,7 +198,7 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
       colnames(graph) <- args$colnames
       qgraph_plot <- qgraph::qgraph(graph,
                                     edge.color = graph_color,
-                                    layout = args$layout_avg,# specifies the color of the edges
+                                    layout = args$layout,# specifies the color of the edges
                                     theme = args$theme,
                                     vsize = args$vsize,
                                     nodeNames = args$nodeNames,
@@ -209,7 +220,7 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
       colnames(graph_inc) <- colnames(output$parameters)
       qgraph_plot1 <- qgraph::qgraph(graph_inc,
                                      edge.color = graph_color,
-                                     layout = args$layout_avg,# specifies the color of the edges
+                                     layout = args$layout,# specifies the color of the edges
                                      theme = args$theme,
                                      vsize = args$vsize,
                                      nodeNames = args$nodeNames,
@@ -227,7 +238,7 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
       qgraph_plot2 <- qgraph::qgraph(graph_exc,
                                      edge.color = graph_color,
                                      # specifies the color of the edges
-                                     layout = args$layout_avg,# specifies the color of the edges
+                                     layout = args$layout,# specifies the color of the edges
                                      theme = args$theme,
                                      vsize = args$vsize,
                                      nodeNames = args$nodeNames,
@@ -254,7 +265,7 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
     colnames(graph_show) <- colnames(output$parameters)
     qgraph_plot <- qgraph::qgraph(graph_show,
                                   edge.color = graph_color,
-                                  layout = args$layout_avg,# specifies the color of the edges
+                                  layout = args$layout,# specifies the color of the edges
                                   theme = args$theme,
                                   vsize = args$vsize,
                                   nodeNames = args$nodeNames,
@@ -276,7 +287,11 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
 
 plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = TRUE, ...) {
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -295,7 +310,7 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
   # Specify default arguments for function
   graph <- output$parameters
   default_args <- list(
-    layout_avg = qgraph::averageLayout(output$parameters*output$structure),
+    layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     evidence_thres = 10,
     theme = "TeamFortress",
     vsize = 10,
@@ -314,7 +329,7 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
   # Plot
   if(dashed){
     graph_dashed <- ifelse(output$inc_BF < args$evidence_thres, "dashed", "solid")
-    qgraph_plot <- qgraph::qgraph(graph, layout = args$layout_avg, lty = graph_dashed,
+    qgraph_plot <- qgraph::qgraph(graph, layout = args$layout, lty = graph_dashed,
                                   theme = args$theme, vsize = args$vsize,
                                   nodeNames = args$nodeNames,
                                   legend = args$legend,
@@ -322,12 +337,11 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
                                   legend.cex = args$legend.cex, ...)
   } else {
     qgraph_plot <- qgraph::qgraph(graph, theme = args$theme,
-                                  layout = args$layout_avg, vsize = args$vsize,
+                                  layout = args$layout, vsize = args$vsize,
                                   nodeNames = args$nodeNames,
                                   legend = args$legend,
                                   label.cex = args$label.cex,
                                   legend.cex = args$legend.cex, ...)
-    
   }
   return(invisible(qgraph_plot))
 }
@@ -338,7 +352,11 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
 
 plot_structure.bgms <- function(output, ...) {
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -351,7 +369,7 @@ plot_structure.bgms <- function(output, ...) {
   
   # Specify default arguments for function
   default_args <- list(
-    layout_avg = qgraph::averageLayout(output$parameters*output$structure),
+    layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     theme = "TeamFortress",
     vsize = 10,
     nodeNames = colnames(output$parameters),
@@ -366,7 +384,7 @@ plot_structure.bgms <- function(output, ...) {
   graph <- output$structure
   colnames(graph) <- colnames(output$parameters)
   # Plot
-  qgraph_plot <- qgraph::qgraph(graph, layout = args$layout_avg,
+  qgraph_plot <- qgraph::qgraph(graph, layout = args$layout,
                                 theme = args$theme, vsize = args$vsize,
                                 nodeNames = args$nodeNames,
                                 legend = args$legend,
@@ -381,7 +399,11 @@ plot_structure.bgms <- function(output, ...) {
 
 plot_parameterHDI.bgms <- function(output, ...) {
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
@@ -450,7 +472,11 @@ plot_parameterHDI.bgms <- function(output, ...) {
 
 plot_centrality.bgms <- function(output, ...){
   
-  fit_args <- extract_arguments(output)
+  if(packageVersion("bgms") < "0.1.3"){
+    stop("Your version of the package bgms is not supported anymore. Please update.")
+  }
+  
+  fit_args <- bgms::extract_arguments(output)
   
   if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
