@@ -145,7 +145,7 @@ plot_edgeevidence.easybgm <- function(output, evidence_thresh = 10, split = FALS
     default_args <- list(
       colors = c("#36648b", "#990000", "#bfbfbf"),
       colnames = colnames(output$parameters),
-      layout = qgraph::averageLayout(output$parameters*output$structure),
+      layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
       theme = "TeamFortress",
       legend = TRUE,
       vsize = 10,
@@ -156,7 +156,6 @@ plot_edgeevidence.easybgm <- function(output, evidence_thresh = 10, split = FALS
     )
   }
 
-
   args <- set_defaults(default_args, ...)
   graph <- output$inc_BF
   diag(graph) <- 1
@@ -282,7 +281,7 @@ plot_network.easybgm <- function(output, exc_prob = 0.5, evidence_thresh = 10,
   
   graph <- output$parameters
   default_args <- list(
-    layout = qgraph::averageLayout(output$parameters*output$structure),
+    layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     evidence_thresh = 10,
     theme = "TeamFortress",
     vsize = 10,
@@ -321,7 +320,6 @@ plot_network.easybgm <- function(output, exc_prob = 0.5, evidence_thresh = 10,
                                   legend.cex = args$legend.cex, 
                                   edge.labels = args$edge.labels, ...)
     
-
   }
   return(invisible(qgraph_plot))
 }
@@ -330,7 +328,7 @@ plot_network.easybgm <- function(output, exc_prob = 0.5, evidence_thresh = 10,
 #' @export
 plot_structure.easybgm <- function(output, ...) {
   default_args <- list(
-    layout = qgraph::averageLayout(output$parameters*output$structure),
+    layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     theme = "TeamFortress",
     vsize = 10,
     nodeNames = colnames(output$parameters),
